# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class VoiceParams(typing_extensions.TypedDict):
    id: str
    """
    The voice ID.
    """

    name: str
    """
    The voice name.
    """

    description: typing.Optional[str]
    """
    The voice description.
    """
