# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ErrorPayloadErrorParams(typing_extensions.TypedDict):
    message: str
    """
    Error message
    """

    code: typing_extensions.NotRequired[str]
    """
    Error code
    """
