# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class AudioChunkPayload(UniversalBaseModel):
    type: typing.Literal["audio_chunk"] = "audio_chunk"
    audio: str = pydantic.Field()
    """
    Base64-encoded audio data (Int16Array for PCM, Uint8Array for mulaw)
    """

    iso_date_time: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    ISO 8601 timestamp (required for first chunk only)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
