# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.extraction_field_type import ExtractionFieldType


class ExtractionFieldParams(typing_extensions.TypedDict):
    name: str
    """
    The field name.
    """

    type: ExtractionFieldType
    """
    The field type.
    """

    description: typing_extensions.NotRequired[typing.Optional[str]]
    """
    Description of the field.
    """
