# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.tool import ToolParams


class ToolsGetResponseParams(typing_extensions.TypedDict):
    tool: ToolParams
