# This file was auto-generated by Fern from our API Definition.

import typing

from .conversations_list_response_conversation import ConversationsListResponseConversationParams
from .conversations_list_response_conversations import ConversationsListResponseConversationsParams

ConversationsListResponseParams = typing.Union[
    ConversationsListResponseConversationsParams, ConversationsListResponseConversationParams
]
