# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .basic_error_error import BasicErrorErrorParams


class BasicErrorParams(typing_extensions.TypedDict):
    error: typing_extensions.NotRequired[BasicErrorErrorParams]
