# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.voice import VoiceParams


class VoicesGetResponseParams(typing_extensions.TypedDict):
    voice: VoiceParams
