# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations


class PhonicEnvironment:
    DEFAULT: PhonicEnvironment

    def __init__(self, *, base: str, production: str):
        self.base = base
        self.production = production


PhonicEnvironment.DEFAULT = PhonicEnvironment(base="https://api.phonic.co/v1", production="wss://api.phonic.co")
