# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .extraction_field import ExtractionFieldParams


class ExtractionSchemaParams(typing_extensions.TypedDict):
    id: str
    """
    The ID of the extraction schema.
    """

    name: str
    """
    The name of the extraction schema.
    """

    prompt: str
    """
    Instructions for how to extract data from conversations.
    """

    fields: typing.Sequence[ExtractionFieldParams]
    """
    Array of field definitions specifying what data to extract.
    """
