# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class SetTwilioCallSidPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["set_twilio_call_sid"]
    encrypted_data: str
    """
    Encrypted Twilio call data
    """
