# This file was auto-generated by Fern from our API Definition.

import typing

from .basic_error import BasicError
from .validation_error import ValidationError

BadRequestErrorBody = typing.Union[ValidationError, BasicError]
