# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .extraction_field import ExtractionField


class ExtractionSchema(UniversalBaseModel):
    id: str = pydantic.Field()
    """
    The ID of the extraction schema.
    """

    name: str = pydantic.Field()
    """
    The name of the extraction schema.
    """

    prompt: str = pydantic.Field()
    """
    Instructions for how to extract data from conversations.
    """

    fields: typing.List[ExtractionField] = pydantic.Field()
    """
    Array of field definitions specifying what data to extract.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
