# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.conversation import ConversationParams


class ConversationsListResponseConversationsParams(typing_extensions.TypedDict):
    conversations: typing.Sequence[ConversationParams]
