# This file was auto-generated by Fern from our API Definition.

import typing

UpdateAgentRequestToolsItemParams = typing.Union[
    typing.Literal["keypad_input"], typing.Literal["natural_conversation_ending"], str
]
