# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.conversation_analysis import ConversationAnalysisParams


class ConversationsGetAnalysisResponseParams(typing_extensions.TypedDict):
    analysis: ConversationAnalysisParams
