# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.agent import AgentParams


class AgentsUpsertResponseParams(typing_extensions.TypedDict):
    agent: AgentParams
    inserted: bool
    """
    Whether the agent was inserted.
    """

    updated: bool
    """
    Whether the agent was updated.
    """
