# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ConversationProjectParams(typing_extensions.TypedDict):
    """
    The project associated with the conversation.
    """

    id: str
    """
    The ID of the project.
    """

    name: str
    """
    The name of the project.
    """
