# This file was auto-generated by Fern from our API Definition.

import typing

from .basic_error import BasicErrorParams
from .validation_error import ValidationErrorParams

BadRequestErrorBodyParams = typing.Union[ValidationErrorParams, BasicErrorParams]
