# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.extraction_schema import ExtractionSchemaParams


class ExtractionSchemasGetResponseParams(typing_extensions.TypedDict):
    extraction_schema: ExtractionSchemaParams
