# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.conversation import ConversationParams


class ConversationsGetResponseParams(typing_extensions.TypedDict):
    conversation: ConversationParams
