# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ValidationErrorErrorParams(typing_extensions.TypedDict):
    message: str
    """
    Error message
    """
