# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class UpdateAgentRequestConfigurationEndpointParams(typing_extensions.TypedDict):
    """
    When not `null`, at the beginning of the conversation the agent will make a POST request to this endpoint when to get configuration options.
    """

    url: str
    """
    URL to call
    """

    headers: typing_extensions.NotRequired[typing.Dict[str, str]]
    """
    Object of key-value pairs.
    """

    timeout_ms: typing_extensions.NotRequired[int]
    """
    Timeout in milliseconds for the endpoint call.
    """
