# This file was auto-generated by Fern from our API Definition.

import typing

CreateToolRequestType = typing.Union[
    typing.Literal["custom_webhook", "custom_websocket", "built_in_transfer_to_phone_number"], typing.Any
]
