# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions
from .conversation_extraction_schema import ConversationExtractionSchemaParams


class ConversationExtractionParams(typing_extensions.TypedDict):
    id: str
    """
    The extraction ID.
    """

    conversation_id: typing_extensions.NotRequired[str]
    """
    The conversation ID.
    """

    schema: ConversationExtractionSchemaParams
    result: typing.Dict[str, typing.Optional[typing.Any]]
    """
    The extracted data.
    """

    error: typing.Optional[str]
    """
    Error message if extraction failed.
    """

    created_at: dt.datetime
    """
    When the extraction was created.
    """
