# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class TaskParams(typing_extensions.TypedDict):
    name: str
    """
    The name of the task.
    """

    description: str
    """
    The description of the task.
    """
