# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ToolCallPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["tool_call"]
    tool_call_id: str
    """
    Unique ID for this tool call
    """

    tool_name: str
    """
    Name of the tool to execute
    """

    parameters: typing.Dict[str, typing.Optional[typing.Any]]
    """
    Parameters for tool execution
    """
