# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ConversationEvaluationResultPromptParams(typing_extensions.TypedDict):
    """
    The evaluation prompt information.
    """

    id: str
    name: str
