# This file was auto-generated by Fern from our API Definition.

import typing

ConfigPayloadOutputFormat = typing.Union[typing.Literal["pcm_44100", "pcm_16000", "pcm_8000", "mulaw_8000"], typing.Any]
