# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.conversation_evaluation_result import ConversationEvaluationResultParams


class ConversationsListEvaluationsResponseParams(typing_extensions.TypedDict):
    evals: typing.Sequence[ConversationEvaluationResultParams]
