# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AgentConfigurationEndpointParams(typing_extensions.TypedDict):
    """
    When not `null`, the agent will call this endpoint to get configuration options.
    """

    url: str
    headers: typing.Dict[str, str]
    timeout_ms: int
    """
    The timeout for the configuration endpoint in milliseconds.
    """
