# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ConversationAgentParams(typing_extensions.TypedDict):
    """
    The agent associated with the conversation.
    """

    id: str
    """
    The ID of the agent.
    """

    name: str
    """
    The name of the agent.
    """

    is_deleted: bool
    """
    Whether the agent has been deleted.
    """
