# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ConversationsExtractDataResponseParams(typing_extensions.TypedDict):
    result: typing.Dict[str, typing.Optional[typing.Any]]
    """
    The extracted data according to the schema.
    """
