# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class DtmfPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["dtmf"]
    digits: str
    """
    DTMF digits to play
    """
