# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class InputTextPayload(UniversalBaseModel):
    type: typing.Literal["input_text"] = "input_text"
    language: str = pydantic.Field()
    """
    Detected ISO 639-1 language code of user speech
    """

    text: str = pydantic.Field()
    """
    Transcribed user speech
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
