# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ToolCallInterruptedPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["tool_call_interrupted"]
    tool_call_id: str
    """
    ID of the interrupted tool call
    """

    tool_name: str
    """
    Name of the interrupted tool
    """

    error_message: str
    """
    Description of why the tool call was interrupted
    """
