# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ConversationsSipOutboundCallResponseParams(typing_extensions.TypedDict):
    conversation_id: str
    """
    The ID of the created conversation.
    """
