# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...requests.project import ProjectParams


class ProjectsGetResponseParams(typing_extensions.TypedDict):
    project: ProjectParams
