# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class AudioChunkResponsePayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["audio_chunk"]
    audio: str
    """
    Base64-encoded AI audio data
    """

    text: str
    """
    Text corresponding to audio chunk
    """
