# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class CreateAgentRequestTemplateVariablesValueParams(typing_extensions.TypedDict):
    default_value: typing.Optional[str]
    is_boosted_keyword: typing_extensions.NotRequired[bool]
