# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .error_payload_error import ErrorPayloadErrorParams


class ErrorPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["error"]
    error: ErrorPayloadErrorParams
    param_errors: typing_extensions.NotRequired[typing.Dict[str, str]]
    """
    Parameter-specific validation errors
    """
