# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.voice import VoiceParams


class VoicesListResponseParams(typing_extensions.TypedDict):
    voices: typing.Sequence[VoiceParams]
