# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .validation_error_error import ValidationErrorErrorParams


class ValidationErrorParams(typing_extensions.TypedDict):
    error: ValidationErrorErrorParams
    param_errors: typing.Dict[str, str]
    """
    Parameter-specific validation errors
    """
