# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AgentsCreateResponse,
        AgentsDeleteResponse,
        AgentsGetResponse,
        AgentsListResponse,
        AgentsUpdateResponse,
        AgentsUpsertResponse,
        UpdateAgentRequestAudioFormat,
        UpdateAgentRequestBackgroundNoise,
        UpdateAgentRequestConfigurationEndpoint,
        UpdateAgentRequestTemplateVariablesValue,
        UpdateAgentRequestToolsItem,
    )
    from .requests import (
        AgentsCreateResponseParams,
        AgentsDeleteResponseParams,
        AgentsGetResponseParams,
        AgentsListResponseParams,
        AgentsUpdateResponseParams,
        AgentsUpsertResponseParams,
        UpdateAgentRequestConfigurationEndpointParams,
        UpdateAgentRequestTemplateVariablesValueParams,
        UpdateAgentRequestToolsItemParams,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AgentsCreateResponse": ".types",
    "AgentsCreateResponseParams": ".requests",
    "AgentsDeleteResponse": ".types",
    "AgentsDeleteResponseParams": ".requests",
    "AgentsGetResponse": ".types",
    "AgentsGetResponseParams": ".requests",
    "AgentsListResponse": ".types",
    "AgentsListResponseParams": ".requests",
    "AgentsUpdateResponse": ".types",
    "AgentsUpdateResponseParams": ".requests",
    "AgentsUpsertResponse": ".types",
    "AgentsUpsertResponseParams": ".requests",
    "UpdateAgentRequestAudioFormat": ".types",
    "UpdateAgentRequestBackgroundNoise": ".types",
    "UpdateAgentRequestConfigurationEndpoint": ".types",
    "UpdateAgentRequestConfigurationEndpointParams": ".requests",
    "UpdateAgentRequestTemplateVariablesValue": ".types",
    "UpdateAgentRequestTemplateVariablesValueParams": ".requests",
    "UpdateAgentRequestToolsItem": ".types",
    "UpdateAgentRequestToolsItemParams": ".requests",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AgentsCreateResponse",
    "AgentsCreateResponseParams",
    "AgentsDeleteResponse",
    "AgentsDeleteResponseParams",
    "AgentsGetResponse",
    "AgentsGetResponseParams",
    "AgentsListResponse",
    "AgentsListResponseParams",
    "AgentsUpdateResponse",
    "AgentsUpdateResponseParams",
    "AgentsUpsertResponse",
    "AgentsUpsertResponseParams",
    "UpdateAgentRequestAudioFormat",
    "UpdateAgentRequestBackgroundNoise",
    "UpdateAgentRequestConfigurationEndpoint",
    "UpdateAgentRequestConfigurationEndpointParams",
    "UpdateAgentRequestTemplateVariablesValue",
    "UpdateAgentRequestTemplateVariablesValueParams",
    "UpdateAgentRequestToolsItem",
    "UpdateAgentRequestToolsItemParams",
]
