# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import typing_extensions


class AudioChunkPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["audio_chunk"]
    audio: str
    """
    Base64-encoded audio data (Int16Array for PCM, Uint8Array for mulaw)
    """

    iso_date_time: typing_extensions.NotRequired[dt.datetime]
    """
    ISO 8601 timestamp (required for first chunk only)
    """
