# This file was auto-generated by Fern from our API Definition.

import datetime as dt

import typing_extensions
from ..types.conversation_evaluation_result_result import ConversationEvaluationResultResult
from .conversation_evaluation_result_prompt import ConversationEvaluationResultPromptParams


class ConversationEvaluationResultParams(typing_extensions.TypedDict):
    id: str
    """
    The evaluation ID.
    """

    result: ConversationEvaluationResultResult
    """
    The evaluation result.
    """

    prompt: ConversationEvaluationResultPromptParams
    """
    The evaluation prompt information.
    """

    created_at: dt.datetime
    """
    When the evaluation was created.
    """
