# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.project import ProjectParams


class ProjectsListResponseParams(typing_extensions.TypedDict):
    projects: typing.Sequence[ProjectParams]
