# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ConversationEvalPromptParams(typing_extensions.TypedDict):
    id: str
    """
    The evaluation prompt ID.
    """

    name: str
    """
    The evaluation prompt name.
    """

    prompt: str
    """
    The evaluation prompt text.
    """
