# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.agent import AgentParams


class AgentsListResponseParams(typing_extensions.TypedDict):
    agents: typing.Sequence[AgentParams]
