# This file was auto-generated by Fern from our API Definition.

import typing

ConversationEvaluationResultResult = typing.Union[
    typing.Literal["successful", "unsuccessful", "undecided", "error"], typing.Any
]
