# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from .conversation_evaluation_result import ConversationEvaluationResultParams


class ConversationEvaluationParams(typing_extensions.TypedDict):
    result: ConversationEvaluationResultParams
    """
    The evaluation result.
    """
