# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ToolCallOutputProcessedPayloadToolParams(typing_extensions.TypedDict):
    id: str
    """
    Tool ID
    """

    name: str
    """
    Human-readable tool name
    """
