# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.extraction_schema import ExtractionSchemaParams


class ExtractionSchemasListResponseParams(typing_extensions.TypedDict):
    extraction_schemas: typing.Sequence[ExtractionSchemaParams]
