# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ToolCallOutputPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["tool_call_output"]
    tool_call_id: str
    """
    ID of the tool call being responded to
    """

    output: typing.Optional[typing.Any]
