# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ConversationCreatedPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["conversation_created"]
    conversation_id: str
    """
    ID of the created conversation
    """
