# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class IsUserSpeakingPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["is_user_speaking"]
    is_user_speaking: bool
    """
    Whether the user is currently speaking
    """
