# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ExtractionSchemasUpdateResponseParams(typing_extensions.TypedDict):
    success: bool
    """
    Whether the extraction schema was updated successfully.
    """
