# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class UserFinishedSpeakingPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["user_finished_speaking"]
