# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.conversation_extraction import ConversationExtractionParams


class ConversationsListExtractionsResponseParams(typing_extensions.TypedDict):
    extractions: typing.Sequence[ConversationExtractionParams]
