# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        Agent,
        AgentAudioFormat,
        AgentBackgroundNoise,
        AgentConfigurationEndpoint,
        AgentProject,
        AgentTemplateVariablesValue,
        AgentToolsItem,
        AssistantChoseNotToRespondPayload,
        AssistantEndedConversationPayload,
        AudioChunkPayload,
        AudioChunkResponsePayload,
        BadRequestErrorBody,
        BasicError,
        BasicErrorError,
        ConfigPayload,
        ConfigPayloadBackgroundNoise,
        ConfigPayloadInputFormat,
        ConfigPayloadOutputFormat,
        Conversation,
        ConversationAgent,
        ConversationAnalysis,
        ConversationBackgroundNoise,
        ConversationCreatedPayload,
        ConversationEndedBy,
        ConversationEval,
        ConversationEvalPrompt,
        ConversationEvaluation,
        ConversationEvaluationResult,
        ConversationEvaluationResultPrompt,
        ConversationEvaluationResultResult,
        ConversationExtraction,
        ConversationExtractionSchema,
        ConversationItem,
        ConversationItemRole,
        ConversationItemToolCallsItem,
        ConversationItemToolCallsItemTool,
        ConversationProject,
        CreateAgentRequest,
        CreateAgentRequestAudioFormat,
        CreateAgentRequestBackgroundNoise,
        CreateAgentRequestConfigurationEndpoint,
        CreateAgentRequestTemplateVariablesValue,
        CreateAgentRequestToolsItem,
        DtmfPayload,
        Error,
        ErrorPayload,
        ErrorPayloadError,
        ExtractionField,
        ExtractionFieldType,
        ExtractionSchema,
        InputCancelledPayload,
        InputTextPayload,
        IsUserSpeakingPayload,
        LanguageCode,
        OutboundCallConfig,
        OutboundCallConfigToolsItem,
        Project,
        ProjectDefaultAgent,
        ReadyToStartConversationPayload,
        SetExternalIdPayload,
        SetTwilioCallSidPayload,
        Task,
        Tool,
        ToolCallInterruptedPayload,
        ToolCallOutputPayload,
        ToolCallOutputProcessedPayload,
        ToolCallOutputProcessedPayloadTool,
        ToolCallPayload,
        ToolEndpointMethod,
        ToolExecutionMode,
        ToolParameter,
        ToolParameterItemType,
        ToolParameterLocation,
        ToolParameterType,
        ToolProject,
        ToolType,
        UpdateSystemPromptPayload,
        UserFinishedSpeakingPayload,
        UserStartedSpeakingPayload,
        ValidationError,
        ValidationErrorError,
        Voice,
    )
    from .errors import (
        BadRequestError,
        ConflictError,
        ForbiddenError,
        GatewayTimeoutError,
        InternalServerError,
        NotFoundError,
        UnauthorizedError,
    )
    from . import agents, conversations, extraction_schemas, projects, tools, voices
    from .agents import (
        AgentsCreateResponse,
        AgentsCreateResponseParams,
        AgentsDeleteResponse,
        AgentsDeleteResponseParams,
        AgentsGetResponse,
        AgentsGetResponseParams,
        AgentsListResponse,
        AgentsListResponseParams,
        AgentsUpdateResponse,
        AgentsUpdateResponseParams,
        AgentsUpsertResponse,
        AgentsUpsertResponseParams,
        UpdateAgentRequestAudioFormat,
        UpdateAgentRequestBackgroundNoise,
        UpdateAgentRequestConfigurationEndpoint,
        UpdateAgentRequestConfigurationEndpointParams,
        UpdateAgentRequestTemplateVariablesValue,
        UpdateAgentRequestTemplateVariablesValueParams,
        UpdateAgentRequestToolsItem,
        UpdateAgentRequestToolsItemParams,
    )
    from .client import AsyncPhonic, Phonic
    from .conversations import (
        ConversationsCancelResponse,
        ConversationsCancelResponseParams,
        ConversationsExtractDataResponse,
        ConversationsExtractDataResponseParams,
        ConversationsGetAnalysisResponse,
        ConversationsGetAnalysisResponseParams,
        ConversationsGetResponse,
        ConversationsGetResponseParams,
        ConversationsListEvaluationsResponse,
        ConversationsListEvaluationsResponseParams,
        ConversationsListExtractionsResponse,
        ConversationsListExtractionsResponseParams,
        ConversationsListResponse,
        ConversationsListResponseConversation,
        ConversationsListResponseConversationParams,
        ConversationsListResponseConversations,
        ConversationsListResponseConversationsParams,
        ConversationsListResponseParams,
        ConversationsOutboundCallResponse,
        ConversationsOutboundCallResponseParams,
        ConversationsSipOutboundCallResponse,
        ConversationsSipOutboundCallResponseParams,
    )
    from .environment import PhonicEnvironment
    from .extraction_schemas import (
        ExtractionSchemasCreateResponse,
        ExtractionSchemasCreateResponseParams,
        ExtractionSchemasDeleteResponse,
        ExtractionSchemasDeleteResponseParams,
        ExtractionSchemasGetResponse,
        ExtractionSchemasGetResponseParams,
        ExtractionSchemasListResponse,
        ExtractionSchemasListResponseParams,
        ExtractionSchemasUpdateResponse,
        ExtractionSchemasUpdateResponseParams,
    )
    from .projects import (
        ProjectsCreateEvalPromptResponse,
        ProjectsCreateEvalPromptResponseParams,
        ProjectsCreateResponse,
        ProjectsCreateResponseParams,
        ProjectsDeleteResponse,
        ProjectsDeleteResponseParams,
        ProjectsGetResponse,
        ProjectsGetResponseParams,
        ProjectsListEvalPromptsResponse,
        ProjectsListEvalPromptsResponseParams,
        ProjectsListResponse,
        ProjectsListResponseParams,
        ProjectsUpdateResponse,
        ProjectsUpdateResponseParams,
    )
    from .requests import (
        AgentConfigurationEndpointParams,
        AgentParams,
        AgentProjectParams,
        AgentTemplateVariablesValueParams,
        AgentToolsItemParams,
        AssistantChoseNotToRespondPayloadParams,
        AssistantEndedConversationPayloadParams,
        AudioChunkPayloadParams,
        AudioChunkResponsePayloadParams,
        BadRequestErrorBodyParams,
        BasicErrorErrorParams,
        BasicErrorParams,
        ConfigPayloadParams,
        ConversationAgentParams,
        ConversationAnalysisParams,
        ConversationCreatedPayloadParams,
        ConversationEvalPromptParams,
        ConversationEvaluationParams,
        ConversationEvaluationResultParams,
        ConversationEvaluationResultPromptParams,
        ConversationExtractionParams,
        ConversationExtractionSchemaParams,
        ConversationItemParams,
        ConversationItemToolCallsItemParams,
        ConversationItemToolCallsItemToolParams,
        ConversationParams,
        ConversationProjectParams,
        CreateAgentRequestConfigurationEndpointParams,
        CreateAgentRequestParams,
        CreateAgentRequestTemplateVariablesValueParams,
        CreateAgentRequestToolsItemParams,
        DtmfPayloadParams,
        ErrorParams,
        ErrorPayloadErrorParams,
        ErrorPayloadParams,
        ExtractionFieldParams,
        ExtractionSchemaParams,
        InputCancelledPayloadParams,
        InputTextPayloadParams,
        IsUserSpeakingPayloadParams,
        OutboundCallConfigParams,
        OutboundCallConfigToolsItemParams,
        ProjectDefaultAgentParams,
        ProjectParams,
        ReadyToStartConversationPayloadParams,
        SetExternalIdPayloadParams,
        SetTwilioCallSidPayloadParams,
        TaskParams,
        ToolCallInterruptedPayloadParams,
        ToolCallOutputPayloadParams,
        ToolCallOutputProcessedPayloadParams,
        ToolCallOutputProcessedPayloadToolParams,
        ToolCallPayloadParams,
        ToolParameterParams,
        ToolParams,
        ToolProjectParams,
        UpdateSystemPromptPayloadParams,
        UserFinishedSpeakingPayloadParams,
        UserStartedSpeakingPayloadParams,
        ValidationErrorErrorParams,
        ValidationErrorParams,
        VoiceParams,
    )
    from .tools import (
        CreateToolRequestEndpointMethod,
        CreateToolRequestExecutionMode,
        CreateToolRequestType,
        ToolsCreateResponse,
        ToolsCreateResponseParams,
        ToolsDeleteResponse,
        ToolsDeleteResponseParams,
        ToolsGetResponse,
        ToolsGetResponseParams,
        ToolsListResponse,
        ToolsListResponseParams,
        ToolsUpdateResponse,
        ToolsUpdateResponseParams,
        UpdateToolRequestEndpointMethod,
        UpdateToolRequestExecutionMode,
        UpdateToolRequestType,
    )
    from .version import __version__
    from .voices import VoicesGetResponse, VoicesGetResponseParams, VoicesListResponse, VoicesListResponseParams
_dynamic_imports: typing.Dict[str, str] = {
    "Agent": ".types",
    "AgentAudioFormat": ".types",
    "AgentBackgroundNoise": ".types",
    "AgentConfigurationEndpoint": ".types",
    "AgentConfigurationEndpointParams": ".requests",
    "AgentParams": ".requests",
    "AgentProject": ".types",
    "AgentProjectParams": ".requests",
    "AgentTemplateVariablesValue": ".types",
    "AgentTemplateVariablesValueParams": ".requests",
    "AgentToolsItem": ".types",
    "AgentToolsItemParams": ".requests",
    "AgentsCreateResponse": ".agents",
    "AgentsCreateResponseParams": ".agents",
    "AgentsDeleteResponse": ".agents",
    "AgentsDeleteResponseParams": ".agents",
    "AgentsGetResponse": ".agents",
    "AgentsGetResponseParams": ".agents",
    "AgentsListResponse": ".agents",
    "AgentsListResponseParams": ".agents",
    "AgentsUpdateResponse": ".agents",
    "AgentsUpdateResponseParams": ".agents",
    "AgentsUpsertResponse": ".agents",
    "AgentsUpsertResponseParams": ".agents",
    "AssistantChoseNotToRespondPayload": ".types",
    "AssistantChoseNotToRespondPayloadParams": ".requests",
    "AssistantEndedConversationPayload": ".types",
    "AssistantEndedConversationPayloadParams": ".requests",
    "AsyncPhonic": ".client",
    "AudioChunkPayload": ".types",
    "AudioChunkPayloadParams": ".requests",
    "AudioChunkResponsePayload": ".types",
    "AudioChunkResponsePayloadParams": ".requests",
    "BadRequestError": ".errors",
    "BadRequestErrorBody": ".types",
    "BadRequestErrorBodyParams": ".requests",
    "BasicError": ".types",
    "BasicErrorError": ".types",
    "BasicErrorErrorParams": ".requests",
    "BasicErrorParams": ".requests",
    "ConfigPayload": ".types",
    "ConfigPayloadBackgroundNoise": ".types",
    "ConfigPayloadInputFormat": ".types",
    "ConfigPayloadOutputFormat": ".types",
    "ConfigPayloadParams": ".requests",
    "ConflictError": ".errors",
    "Conversation": ".types",
    "ConversationAgent": ".types",
    "ConversationAgentParams": ".requests",
    "ConversationAnalysis": ".types",
    "ConversationAnalysisParams": ".requests",
    "ConversationBackgroundNoise": ".types",
    "ConversationCreatedPayload": ".types",
    "ConversationCreatedPayloadParams": ".requests",
    "ConversationEndedBy": ".types",
    "ConversationEval": ".types",
    "ConversationEvalPrompt": ".types",
    "ConversationEvalPromptParams": ".requests",
    "ConversationEvaluation": ".types",
    "ConversationEvaluationParams": ".requests",
    "ConversationEvaluationResult": ".types",
    "ConversationEvaluationResultParams": ".requests",
    "ConversationEvaluationResultPrompt": ".types",
    "ConversationEvaluationResultPromptParams": ".requests",
    "ConversationEvaluationResultResult": ".types",
    "ConversationExtraction": ".types",
    "ConversationExtractionParams": ".requests",
    "ConversationExtractionSchema": ".types",
    "ConversationExtractionSchemaParams": ".requests",
    "ConversationItem": ".types",
    "ConversationItemParams": ".requests",
    "ConversationItemRole": ".types",
    "ConversationItemToolCallsItem": ".types",
    "ConversationItemToolCallsItemParams": ".requests",
    "ConversationItemToolCallsItemTool": ".types",
    "ConversationItemToolCallsItemToolParams": ".requests",
    "ConversationParams": ".requests",
    "ConversationProject": ".types",
    "ConversationProjectParams": ".requests",
    "ConversationsCancelResponse": ".conversations",
    "ConversationsCancelResponseParams": ".conversations",
    "ConversationsExtractDataResponse": ".conversations",
    "ConversationsExtractDataResponseParams": ".conversations",
    "ConversationsGetAnalysisResponse": ".conversations",
    "ConversationsGetAnalysisResponseParams": ".conversations",
    "ConversationsGetResponse": ".conversations",
    "ConversationsGetResponseParams": ".conversations",
    "ConversationsListEvaluationsResponse": ".conversations",
    "ConversationsListEvaluationsResponseParams": ".conversations",
    "ConversationsListExtractionsResponse": ".conversations",
    "ConversationsListExtractionsResponseParams": ".conversations",
    "ConversationsListResponse": ".conversations",
    "ConversationsListResponseConversation": ".conversations",
    "ConversationsListResponseConversationParams": ".conversations",
    "ConversationsListResponseConversations": ".conversations",
    "ConversationsListResponseConversationsParams": ".conversations",
    "ConversationsListResponseParams": ".conversations",
    "ConversationsOutboundCallResponse": ".conversations",
    "ConversationsOutboundCallResponseParams": ".conversations",
    "ConversationsSipOutboundCallResponse": ".conversations",
    "ConversationsSipOutboundCallResponseParams": ".conversations",
    "CreateAgentRequest": ".types",
    "CreateAgentRequestAudioFormat": ".types",
    "CreateAgentRequestBackgroundNoise": ".types",
    "CreateAgentRequestConfigurationEndpoint": ".types",
    "CreateAgentRequestConfigurationEndpointParams": ".requests",
    "CreateAgentRequestParams": ".requests",
    "CreateAgentRequestTemplateVariablesValue": ".types",
    "CreateAgentRequestTemplateVariablesValueParams": ".requests",
    "CreateAgentRequestToolsItem": ".types",
    "CreateAgentRequestToolsItemParams": ".requests",
    "CreateToolRequestEndpointMethod": ".tools",
    "CreateToolRequestExecutionMode": ".tools",
    "CreateToolRequestType": ".tools",
    "DtmfPayload": ".types",
    "DtmfPayloadParams": ".requests",
    "Error": ".types",
    "ErrorParams": ".requests",
    "ErrorPayload": ".types",
    "ErrorPayloadError": ".types",
    "ErrorPayloadErrorParams": ".requests",
    "ErrorPayloadParams": ".requests",
    "ExtractionField": ".types",
    "ExtractionFieldParams": ".requests",
    "ExtractionFieldType": ".types",
    "ExtractionSchema": ".types",
    "ExtractionSchemaParams": ".requests",
    "ExtractionSchemasCreateResponse": ".extraction_schemas",
    "ExtractionSchemasCreateResponseParams": ".extraction_schemas",
    "ExtractionSchemasDeleteResponse": ".extraction_schemas",
    "ExtractionSchemasDeleteResponseParams": ".extraction_schemas",
    "ExtractionSchemasGetResponse": ".extraction_schemas",
    "ExtractionSchemasGetResponseParams": ".extraction_schemas",
    "ExtractionSchemasListResponse": ".extraction_schemas",
    "ExtractionSchemasListResponseParams": ".extraction_schemas",
    "ExtractionSchemasUpdateResponse": ".extraction_schemas",
    "ExtractionSchemasUpdateResponseParams": ".extraction_schemas",
    "ForbiddenError": ".errors",
    "GatewayTimeoutError": ".errors",
    "InputCancelledPayload": ".types",
    "InputCancelledPayloadParams": ".requests",
    "InputTextPayload": ".types",
    "InputTextPayloadParams": ".requests",
    "InternalServerError": ".errors",
    "IsUserSpeakingPayload": ".types",
    "IsUserSpeakingPayloadParams": ".requests",
    "LanguageCode": ".types",
    "NotFoundError": ".errors",
    "OutboundCallConfig": ".types",
    "OutboundCallConfigParams": ".requests",
    "OutboundCallConfigToolsItem": ".types",
    "OutboundCallConfigToolsItemParams": ".requests",
    "Phonic": ".client",
    "PhonicEnvironment": ".environment",
    "Project": ".types",
    "ProjectDefaultAgent": ".types",
    "ProjectDefaultAgentParams": ".requests",
    "ProjectParams": ".requests",
    "ProjectsCreateEvalPromptResponse": ".projects",
    "ProjectsCreateEvalPromptResponseParams": ".projects",
    "ProjectsCreateResponse": ".projects",
    "ProjectsCreateResponseParams": ".projects",
    "ProjectsDeleteResponse": ".projects",
    "ProjectsDeleteResponseParams": ".projects",
    "ProjectsGetResponse": ".projects",
    "ProjectsGetResponseParams": ".projects",
    "ProjectsListEvalPromptsResponse": ".projects",
    "ProjectsListEvalPromptsResponseParams": ".projects",
    "ProjectsListResponse": ".projects",
    "ProjectsListResponseParams": ".projects",
    "ProjectsUpdateResponse": ".projects",
    "ProjectsUpdateResponseParams": ".projects",
    "ReadyToStartConversationPayload": ".types",
    "ReadyToStartConversationPayloadParams": ".requests",
    "SetExternalIdPayload": ".types",
    "SetExternalIdPayloadParams": ".requests",
    "SetTwilioCallSidPayload": ".types",
    "SetTwilioCallSidPayloadParams": ".requests",
    "Task": ".types",
    "TaskParams": ".requests",
    "Tool": ".types",
    "ToolCallInterruptedPayload": ".types",
    "ToolCallInterruptedPayloadParams": ".requests",
    "ToolCallOutputPayload": ".types",
    "ToolCallOutputPayloadParams": ".requests",
    "ToolCallOutputProcessedPayload": ".types",
    "ToolCallOutputProcessedPayloadParams": ".requests",
    "ToolCallOutputProcessedPayloadTool": ".types",
    "ToolCallOutputProcessedPayloadToolParams": ".requests",
    "ToolCallPayload": ".types",
    "ToolCallPayloadParams": ".requests",
    "ToolEndpointMethod": ".types",
    "ToolExecutionMode": ".types",
    "ToolParameter": ".types",
    "ToolParameterItemType": ".types",
    "ToolParameterLocation": ".types",
    "ToolParameterParams": ".requests",
    "ToolParameterType": ".types",
    "ToolParams": ".requests",
    "ToolProject": ".types",
    "ToolProjectParams": ".requests",
    "ToolType": ".types",
    "ToolsCreateResponse": ".tools",
    "ToolsCreateResponseParams": ".tools",
    "ToolsDeleteResponse": ".tools",
    "ToolsDeleteResponseParams": ".tools",
    "ToolsGetResponse": ".tools",
    "ToolsGetResponseParams": ".tools",
    "ToolsListResponse": ".tools",
    "ToolsListResponseParams": ".tools",
    "ToolsUpdateResponse": ".tools",
    "ToolsUpdateResponseParams": ".tools",
    "UnauthorizedError": ".errors",
    "UpdateAgentRequestAudioFormat": ".agents",
    "UpdateAgentRequestBackgroundNoise": ".agents",
    "UpdateAgentRequestConfigurationEndpoint": ".agents",
    "UpdateAgentRequestConfigurationEndpointParams": ".agents",
    "UpdateAgentRequestTemplateVariablesValue": ".agents",
    "UpdateAgentRequestTemplateVariablesValueParams": ".agents",
    "UpdateAgentRequestToolsItem": ".agents",
    "UpdateAgentRequestToolsItemParams": ".agents",
    "UpdateSystemPromptPayload": ".types",
    "UpdateSystemPromptPayloadParams": ".requests",
    "UpdateToolRequestEndpointMethod": ".tools",
    "UpdateToolRequestExecutionMode": ".tools",
    "UpdateToolRequestType": ".tools",
    "UserFinishedSpeakingPayload": ".types",
    "UserFinishedSpeakingPayloadParams": ".requests",
    "UserStartedSpeakingPayload": ".types",
    "UserStartedSpeakingPayloadParams": ".requests",
    "ValidationError": ".types",
    "ValidationErrorError": ".types",
    "ValidationErrorErrorParams": ".requests",
    "ValidationErrorParams": ".requests",
    "Voice": ".types",
    "VoiceParams": ".requests",
    "VoicesGetResponse": ".voices",
    "VoicesGetResponseParams": ".voices",
    "VoicesListResponse": ".voices",
    "VoicesListResponseParams": ".voices",
    "__version__": ".version",
    "agents": ".agents",
    "conversations": ".conversations",
    "extraction_schemas": ".extraction_schemas",
    "projects": ".projects",
    "tools": ".tools",
    "voices": ".voices",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "Agent",
    "AgentAudioFormat",
    "AgentBackgroundNoise",
    "AgentConfigurationEndpoint",
    "AgentConfigurationEndpointParams",
    "AgentParams",
    "AgentProject",
    "AgentProjectParams",
    "AgentTemplateVariablesValue",
    "AgentTemplateVariablesValueParams",
    "AgentToolsItem",
    "AgentToolsItemParams",
    "AgentsCreateResponse",
    "AgentsCreateResponseParams",
    "AgentsDeleteResponse",
    "AgentsDeleteResponseParams",
    "AgentsGetResponse",
    "AgentsGetResponseParams",
    "AgentsListResponse",
    "AgentsListResponseParams",
    "AgentsUpdateResponse",
    "AgentsUpdateResponseParams",
    "AgentsUpsertResponse",
    "AgentsUpsertResponseParams",
    "AssistantChoseNotToRespondPayload",
    "AssistantChoseNotToRespondPayloadParams",
    "AssistantEndedConversationPayload",
    "AssistantEndedConversationPayloadParams",
    "AsyncPhonic",
    "AudioChunkPayload",
    "AudioChunkPayloadParams",
    "AudioChunkResponsePayload",
    "AudioChunkResponsePayloadParams",
    "BadRequestError",
    "BadRequestErrorBody",
    "BadRequestErrorBodyParams",
    "BasicError",
    "BasicErrorError",
    "BasicErrorErrorParams",
    "BasicErrorParams",
    "ConfigPayload",
    "ConfigPayloadBackgroundNoise",
    "ConfigPayloadInputFormat",
    "ConfigPayloadOutputFormat",
    "ConfigPayloadParams",
    "ConflictError",
    "Conversation",
    "ConversationAgent",
    "ConversationAgentParams",
    "ConversationAnalysis",
    "ConversationAnalysisParams",
    "ConversationBackgroundNoise",
    "ConversationCreatedPayload",
    "ConversationCreatedPayloadParams",
    "ConversationEndedBy",
    "ConversationEval",
    "ConversationEvalPrompt",
    "ConversationEvalPromptParams",
    "ConversationEvaluation",
    "ConversationEvaluationParams",
    "ConversationEvaluationResult",
    "ConversationEvaluationResultParams",
    "ConversationEvaluationResultPrompt",
    "ConversationEvaluationResultPromptParams",
    "ConversationEvaluationResultResult",
    "ConversationExtraction",
    "ConversationExtractionParams",
    "ConversationExtractionSchema",
    "ConversationExtractionSchemaParams",
    "ConversationItem",
    "ConversationItemParams",
    "ConversationItemRole",
    "ConversationItemToolCallsItem",
    "ConversationItemToolCallsItemParams",
    "ConversationItemToolCallsItemTool",
    "ConversationItemToolCallsItemToolParams",
    "ConversationParams",
    "ConversationProject",
    "ConversationProjectParams",
    "ConversationsCancelResponse",
    "ConversationsCancelResponseParams",
    "ConversationsExtractDataResponse",
    "ConversationsExtractDataResponseParams",
    "ConversationsGetAnalysisResponse",
    "ConversationsGetAnalysisResponseParams",
    "ConversationsGetResponse",
    "ConversationsGetResponseParams",
    "ConversationsListEvaluationsResponse",
    "ConversationsListEvaluationsResponseParams",
    "ConversationsListExtractionsResponse",
    "ConversationsListExtractionsResponseParams",
    "ConversationsListResponse",
    "ConversationsListResponseConversation",
    "ConversationsListResponseConversationParams",
    "ConversationsListResponseConversations",
    "ConversationsListResponseConversationsParams",
    "ConversationsListResponseParams",
    "ConversationsOutboundCallResponse",
    "ConversationsOutboundCallResponseParams",
    "ConversationsSipOutboundCallResponse",
    "ConversationsSipOutboundCallResponseParams",
    "CreateAgentRequest",
    "CreateAgentRequestAudioFormat",
    "CreateAgentRequestBackgroundNoise",
    "CreateAgentRequestConfigurationEndpoint",
    "CreateAgentRequestConfigurationEndpointParams",
    "CreateAgentRequestParams",
    "CreateAgentRequestTemplateVariablesValue",
    "CreateAgentRequestTemplateVariablesValueParams",
    "CreateAgentRequestToolsItem",
    "CreateAgentRequestToolsItemParams",
    "CreateToolRequestEndpointMethod",
    "CreateToolRequestExecutionMode",
    "CreateToolRequestType",
    "DtmfPayload",
    "DtmfPayloadParams",
    "Error",
    "ErrorParams",
    "ErrorPayload",
    "ErrorPayloadError",
    "ErrorPayloadErrorParams",
    "ErrorPayloadParams",
    "ExtractionField",
    "ExtractionFieldParams",
    "ExtractionFieldType",
    "ExtractionSchema",
    "ExtractionSchemaParams",
    "ExtractionSchemasCreateResponse",
    "ExtractionSchemasCreateResponseParams",
    "ExtractionSchemasDeleteResponse",
    "ExtractionSchemasDeleteResponseParams",
    "ExtractionSchemasGetResponse",
    "ExtractionSchemasGetResponseParams",
    "ExtractionSchemasListResponse",
    "ExtractionSchemasListResponseParams",
    "ExtractionSchemasUpdateResponse",
    "ExtractionSchemasUpdateResponseParams",
    "ForbiddenError",
    "GatewayTimeoutError",
    "InputCancelledPayload",
    "InputCancelledPayloadParams",
    "InputTextPayload",
    "InputTextPayloadParams",
    "InternalServerError",
    "IsUserSpeakingPayload",
    "IsUserSpeakingPayloadParams",
    "LanguageCode",
    "NotFoundError",
    "OutboundCallConfig",
    "OutboundCallConfigParams",
    "OutboundCallConfigToolsItem",
    "OutboundCallConfigToolsItemParams",
    "Phonic",
    "PhonicEnvironment",
    "Project",
    "ProjectDefaultAgent",
    "ProjectDefaultAgentParams",
    "ProjectParams",
    "ProjectsCreateEvalPromptResponse",
    "ProjectsCreateEvalPromptResponseParams",
    "ProjectsCreateResponse",
    "ProjectsCreateResponseParams",
    "ProjectsDeleteResponse",
    "ProjectsDeleteResponseParams",
    "ProjectsGetResponse",
    "ProjectsGetResponseParams",
    "ProjectsListEvalPromptsResponse",
    "ProjectsListEvalPromptsResponseParams",
    "ProjectsListResponse",
    "ProjectsListResponseParams",
    "ProjectsUpdateResponse",
    "ProjectsUpdateResponseParams",
    "ReadyToStartConversationPayload",
    "ReadyToStartConversationPayloadParams",
    "SetExternalIdPayload",
    "SetExternalIdPayloadParams",
    "SetTwilioCallSidPayload",
    "SetTwilioCallSidPayloadParams",
    "Task",
    "TaskParams",
    "Tool",
    "ToolCallInterruptedPayload",
    "ToolCallInterruptedPayloadParams",
    "ToolCallOutputPayload",
    "ToolCallOutputPayloadParams",
    "ToolCallOutputProcessedPayload",
    "ToolCallOutputProcessedPayloadParams",
    "ToolCallOutputProcessedPayloadTool",
    "ToolCallOutputProcessedPayloadToolParams",
    "ToolCallPayload",
    "ToolCallPayloadParams",
    "ToolEndpointMethod",
    "ToolExecutionMode",
    "ToolParameter",
    "ToolParameterItemType",
    "ToolParameterLocation",
    "ToolParameterParams",
    "ToolParameterType",
    "ToolParams",
    "ToolProject",
    "ToolProjectParams",
    "ToolType",
    "ToolsCreateResponse",
    "ToolsCreateResponseParams",
    "ToolsDeleteResponse",
    "ToolsDeleteResponseParams",
    "ToolsGetResponse",
    "ToolsGetResponseParams",
    "ToolsListResponse",
    "ToolsListResponseParams",
    "ToolsUpdateResponse",
    "ToolsUpdateResponseParams",
    "UnauthorizedError",
    "UpdateAgentRequestAudioFormat",
    "UpdateAgentRequestBackgroundNoise",
    "UpdateAgentRequestConfigurationEndpoint",
    "UpdateAgentRequestConfigurationEndpointParams",
    "UpdateAgentRequestTemplateVariablesValue",
    "UpdateAgentRequestTemplateVariablesValueParams",
    "UpdateAgentRequestToolsItem",
    "UpdateAgentRequestToolsItemParams",
    "UpdateSystemPromptPayload",
    "UpdateSystemPromptPayloadParams",
    "UpdateToolRequestEndpointMethod",
    "UpdateToolRequestExecutionMode",
    "UpdateToolRequestType",
    "UserFinishedSpeakingPayload",
    "UserFinishedSpeakingPayloadParams",
    "UserStartedSpeakingPayload",
    "UserStartedSpeakingPayloadParams",
    "ValidationError",
    "ValidationErrorError",
    "ValidationErrorErrorParams",
    "ValidationErrorParams",
    "Voice",
    "VoiceParams",
    "VoicesGetResponse",
    "VoicesGetResponseParams",
    "VoicesListResponse",
    "VoicesListResponseParams",
    "__version__",
    "agents",
    "conversations",
    "extraction_schemas",
    "projects",
    "tools",
    "voices",
]
