# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.tool import ToolParams


class ToolsListResponseParams(typing_extensions.TypedDict):
    tools: typing.Sequence[ToolParams]
