# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class AgentProjectParams(typing_extensions.TypedDict):
    """
    The project the agent belongs to.
    """

    id: str
    name: str
