# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class SetExternalIdPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["set_external_id"]
    external_id: str
    """
    External ID to associate with conversation
    """
