# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class UpdateSystemPromptPayloadParams(typing_extensions.TypedDict):
    type: typing.Literal["update_system_prompt"]
    system_prompt: str
    """
    New system prompt (cannot contain template variables)
    """
