# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .project_default_agent import ProjectDefaultAgentParams


class ProjectParams(typing_extensions.TypedDict):
    id: str
    """
    The ID of the project.
    """

    name: str
    """
    The name of the project.
    """

    default_agent: typing.Optional[ProjectDefaultAgentParams]
    """
    The project's default agent.
    """
