# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class ConversationAnalysisParams(typing_extensions.TypedDict):
    latencies_ms: typing.Sequence[float]
    """
    Latencies between turns in milliseconds.
    """

    interruptions_count: int
    """
    Number of interruptions in the conversation.
    """
