# This file was auto-generated by Fern from our API Definition.

import typing

LanguageCode = typing.Union[
    typing.Literal[
        "ar", "zh", "cs", "da", "nl", "en", "fr", "de", "id", "it", "ja", "ko", "pl", "pt", "ru", "es", "sv", "tr", "vi"
    ],
    typing.Any,
]
