# This file was auto-generated by Fern from our API Definition.

import typing

ConversationEndedBy = typing.Union[
    typing.Literal["user", "user_canceled", "user_validation_failed", "assistant", "error"], typing.Any
]
