# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ProjectDefaultAgentParams(typing_extensions.TypedDict):
    """
    The project's default agent.
    """

    id: str
    """
    The ID of the project's default agent.
    """

    name: str
    """
    The name of the project's default agent.
    """
