# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ...requests.conversation_eval_prompt import ConversationEvalPromptParams


class ProjectsListEvalPromptsResponseParams(typing_extensions.TypedDict):
    conversation_eval_prompts: typing.Sequence[ConversationEvalPromptParams]
